@@ -1,7 +1,7 @@
 
 
 __title__ = 'redis_collections'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __author__ = 'Jan Javorek'
 __license__ = 'ISC'
 __copyright__ = 'Copyright 2013 Jan Javorek'
@@ -11,4 +11,4 @@ from .base import RedisCollection
 
 from .sets import Set
 from .lists import List
-from .dicts import Dict
+from .dicts import Dict, Counter
